@@ -26,3 +26,22 @@ sub scrape {
 }
 
 1;
+__END__
+
+=head1 NAME
+
+WWW::MobileCarrierJP::ThirdForce::PictogramInfo - get PictogramInfo informtation from ThirdForce site.
+
+=head1 SYNOPSIS
+
+    use WWW::MobileCarrierJP::ThirdForce::PictogramInfo;
+    WWW::MobileCarrierJP::ThirdForce::PictogramInfo->scrape();
+
+=head1 AUTHOR
+
+Tokuhiro Matsuno < tokuhirom gmail com >
+
+=head1 SEE ALSO
+
+L<WWW::MobileCarrierJP>
+
